#!/bin/sh
# Update the X font indexes:
if [ -x /usr/X11R6/bin/fc-cache ]; then
  /usr/X11R6/bin/fc-cache -f
fi
# else we'll catch it later with setup.fontconfig :-)
# make links:
( cd usr/X11R6/lib64 ; rm -rf libfontconfig.so.1 )
( cd usr/X11R6/lib64 ; ln -sf libfontconfig.so.1.0.4 libfontconfig.so.1 )
( cd usr/X11R6/lib64 ; rm -rf libfontconfig.so )
( cd usr/X11R6/lib64 ; ln -sf libfontconfig.so.1.0.4 libfontconfig.so )
